# CHANGELOG


## [0.0.4](https://github.com/growthbook/growthbook-openfeature-provider-python/compare/0.0.3...0.0.4) (2025-05-06)


### Bug Fixes

* handle async contexts ([d3b7027](https://github.com/growthbook/growthbook-openfeature-provider-python/commit/d3b70273ba925fc319db2bce234c14d22ab06eb1))

## [0.0.3](https://github.com/growthbook/growthbook-openfeature-provider-python/compare/v0.0.2...0.0.3) (2025-05-06)


### Bug Fixes

* handle nested async contexts ([5fbd9a2](https://github.com/growthbook/growthbook-openfeature-provider-python/commit/5fbd9a2a3b5ea6b8ec149dbb03f8b31fee5d404f))

## [0.0.2](https://github.com/growthbook/growthbook-openfeature-provider-python/compare/v0.0.1...0.0.2) (2025-05-06)


### Bug Fixes

* handle nested async contexts ([5fbd9a2](https://github.com/growthbook/growthbook-openfeature-provider-python/commit/5fbd9a2a3b5ea6b8ec149dbb03f8b31fee5d404f))

## v0.0.2 (2025-03-20)


## v0.0.1 (2025-03-11)
